/**
 * Modal
 * Dependencies:
 * - @gorhom/bottom-sheet.
 *
 * Props:
 * - All `BottomSheetModalProps` props.
 * - `title` (string | undefined): Optional title for the modal header.
 *
 * Usage Example:
 * import { Modal, useModal } from '@gorhom/bottom-sheet';
 *
 * function DisplayModal() {
 *   const { ref, present, dismiss } = useModal();
 *
 *   return (
 *     <View>
 *       <Modal
 *         snapPoints={['60%']} // optional
 *         title="Modal Title"
 *         ref={ref}
 *       >
 *         Modal Content
 *       </Modal>
 *     </View>
 *   );
 * }
 *
 */
import type { BottomSheetBackdropProps, BottomSheetModalProps } from '@gorhom/bottom-sheet';
import { BottomSheetModal } from '@gorhom/bottom-sheet';
import * as React from 'react';
export declare const useModal: () => {
    ref: React.RefObject<BottomSheetModal>;
    present: (data?: any) => void;
    dismiss: () => void;
};
export declare const Modal: React.ForwardRefExoticComponent<BottomSheetModalProps<any> & {
    title?: string;
} & React.RefAttributes<BottomSheetModal>>;
export declare const renderBackdrop: (props: BottomSheetBackdropProps) => React.JSX.Element;
//# sourceMappingURL=modal.d.ts.map